/*
 * bytetape.h - part of btype
 * Copyright (C) 2005 Michael Pyne <michael.pyne@kdemail.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#ifndef BYTETAPE_H
#define BYTETAPE_H

#include <qcstring.h>
#include <ksharedptr.h>

class ByteTapeData : public KShared
{
public:
    ByteTapeData(int p = 0) : KShared(), pos(p) { }

    int pos;
};

typedef KSharedPtr<ByteTapeData> ByteTapeDataPtr;

// Utility class to add the notion of a current position to a QByteArray.
class ByteTape : public QByteArray
{
public:
    ByteTape();
    virtual ~ByteTape();
    ByteTape(const QByteArray &data, int pos = 0);

    // Copy ctor.  Notice that both the parent and clone share the same
    // current position.  Affecting it in one object will affect it in the
    // other.
    ByteTape(ByteTape &other);

    // Assignment operator.  The same warning about sharing the current
    // position for the copy ctor applies here.
    ByteTape &operator=(ByteTape &other);

    // Gets the character at the current position.
    char operator*() const;

    // Advance/Retreat the current position.
    ByteTape &operator++();
    ByteTape &operator--();

    // Like above, but with an adjustable factor.
    ByteTape &operator +=(int i);
    ByteTape &operator -=(int i);

    // Override inherited.  Returns the relative position from the current
    // position to the given character.  Only searches to the right.
    int find(char ch) const;

    // Returns/Set the current position.
    int pos() const { return m_data-> pos; }
    void setPos(int pos);

    // Returns true if the current position is at the end of the data.
    bool eof() const;

    // Convienience method to extract some data between current position and
    // some other (relative) position.  The current position is included, and
    // the other position is excluded.
    QByteArray slice(int size) const;

private:
    ByteTapeDataPtr m_data;
};

#endif /* BYTETAPE_H */

// vim: set et ts=8 sw=4:
