/*
 * main.cpp - part of btype
 * Copyright (C) 2005 Michael Pyne <michael.pyne@kdemail.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include <kapplication.h>
#include <kstatusbar.h>
#include <kaboutdata.h>
#include <kdebug.h>
#include <kcmdlineargs.h>
#include <kstdaction.h>
#include <klocale.h>

#include "main.h"
#include "mainform.h"

TestApp::TestApp(QWidget *parent) : KMainWindow(parent, "testappmainwin")
{
    m_main = new MainForm(this);
    KStdAction::open(m_main, SLOT(open()), actionCollection());
    KStdAction::quit(kapp, SLOT(quit()), actionCollection());
    KStdAction::save(m_main, SLOT(save()), actionCollection());
    KStdAction::saveAs(m_main, SLOT(saveAs()), actionCollection());
    KStdAction::openNew(m_main, SLOT(newDocument()), actionCollection());

    setCentralWidget(m_main);
    statusBar()->insertItem("", 0);

    connect(m_main, SIGNAL(newHash(const QString &)),
            this,   SLOT(slotNewHash(const QString &)));
    connect(m_main, SIGNAL(opened(const QString &)),
            this,   SLOT(slotOpened(const QString &)));
    connect(m_main, SIGNAL(dirty(bool)),
            this,   SLOT(slotDirty(bool)));

    setupGUI();
}

void TestApp::slotNewHash(const QString &hash)
{
    if(hash.isEmpty())
        statusBar()->changeItem("", 0);
    else
        statusBar()->changeItem(i18n("Object hash: %1").arg(hash), 0);
}

void TestApp::slotDirty(bool isDirty)
{
    setCaption(caption(), isDirty);
}

bool TestApp::queryClose()
{
    return m_main->queryClose();
}

void TestApp::slotOpened(const QString &file)
{
    setCaption(file, m_main->isDirty());
}

int main(int argc, char **argv)
{
    KAboutData about("btype-test", I18N_NOOP("btype Tester"), "0.4.1",
            I18N_NOOP("A viewer for the BitTorrent .torrent files.  Also a test of "
            "the underlying b-encoding library."), KAboutData::License_GPL,
            "(c) 2005 Michael Pyne", "http://grammarian.homelinux.net/");

    about.setLicense(KAboutData::License_BSD);
    about.addAuthor("Michael Pyne", 0, "michael.pyne@kdemail.net", "http://grammarian.homelinux.net/");
    KCmdLineArgs::init(argc, argv, &about);

    KApplication a;
    TestApp *app = new TestApp;

    a.setMainWidget(app);
    a.connect(&a, SIGNAL(lastWindowClosed()), SLOT(quit()));
    app->show();

    return a.exec();
}

#include "main.moc"

// vim: set et sw=4 ts=8:
