/*
 * sha1hash.cpp - part of btype
 * Copyright (C) 2005 Michael Pyne <michael.pyne@kdemail.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include <qstring.h>

#include "sha1hash.h"
#include "sha1.h"

SHA1Hash::SHA1Hash(const void *pos) : m_hash(NumSHABytes)
{
    m_hash.duplicate(static_cast<const char *>(pos), NumSHABytes);
}

SHA1Hash::SHA1Hash(const QByteArray &array) : m_hash(NumSHABytes)
{
    m_hash.duplicate(array, NumSHABytes);
}

SHA1Hash::SHA1Hash(SHA1 &sha) : m_hash(20)
{
    m_hash.duplicate(static_cast<const char *>(static_cast<const void *>(sha.hash())), 20);
}

QString SHA1Hash::hex(bool uppercase) const
{
    QString result;
    const char *const digits = "0123456789ABCDEF";

    for(unsigned i = 0; i < NumSHABytes; ++i) {
        char ch = m_hash[i];

        result.append(digits[(ch >> 4) & 0x0F]);
        result.append(digits[ch & 0x0F]);
    }

    if(!uppercase)
        return result.lower();

    return result;
}

bool SHA1Hash::operator==(const SHA1Hash &other) const
{
    return m_hash == other.m_hash;
}

bool SHA1Hash::operator!=(const SHA1Hash &other) const
{
    return m_hash != other.m_hash;
}

// vim: set et ts=8 sw=4:
