/*
 * sha1hash.h - part of btype
 * Copyright (C) 2005 Michael Pyne <michael.pyne@kdemail.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#ifndef BTYPE_SHA1_HASH
#define BTYPE_SHA1_HASH

#include <qcstring.h>

class QString;
class SHA1;

/**
 * Simple wrapper around a 20-byte SHA1 hash.
 */
class SHA1Hash
{
public:
    // Constructs the hash from the 20-bytes starting at pos.
    SHA1Hash(const void *pos);

    // Constructs the hash from array, which should have 20 (or more) bytes.
    SHA1Hash(const QByteArray &array);

    // Constructs for a SHA1 object, assuming that process() has already been
    // called.
    SHA1Hash(SHA1 &sha);

    // Returns a string consisting of the hash converted to hexadecimal.
    QString hex(bool uppercase = true) const;

    // The number of bytes used in a SHA1 hash.
    static const unsigned NumSHABytes = 20;

    bool operator==(const SHA1Hash &other) const;
    bool operator!=(const SHA1Hash &other) const;

private:
    QByteArray m_hash;
};

#endif /* BTYPE_SHA1_HASH */

// vim: set et ts=8 sw=4:
